@@ -46,10 +46,10 @@ import org.objectweb.asm.test.ClassFile;
  *
  * @author Eric Bruneton
  */
-public class TryCatchBlockSorterTest extends AsmTest {
+class TryCatchBlockSorterTest extends AsmTest {
 
   @Test
-  public void testConstructor() {
+  void testConstructor() {
     assertDoesNotThrow(
         () -> new TryCatchBlockSorter(null, Opcodes.ACC_PUBLIC, "name", "()V", null, null));
     assertThrows(
@@ -59,7 +59,7 @@ public class TryCatchBlockSorterTest extends AsmTest {
 
   @ParameterizedTest
   @MethodSource(ALL_CLASSES_AND_LATEST_API)
-  public void testAllMethods_precompileClass(
+  void testAllMethods_precompileClass(
       final PrecompiledClass classParameter, final Api apiParameter) {
     ClassReader classReader = new ClassReader(classParameter.getBytes());
     ClassWriter classWriter = new ClassWriter(0);
@@ -84,12 +84,11 @@ public class TryCatchBlockSorterTest extends AsmTest {
 
     classReader.accept(classVisitor, 0);
 
+    ClassFile classFile = new ClassFile(classWriter.toByteArray());
     if (classParameter.isNotCompatibleWithCurrentJdk()) {
-      assertThrows(
-          UnsupportedClassVersionError.class,
-          () -> new ClassFile(classWriter.toByteArray()).newInstance());
+      assertThrows(UnsupportedClassVersionError.class, () -> classFile.newInstance());
     } else {
-      assertDoesNotThrow(() -> new ClassFile(classWriter.toByteArray()).newInstance());
+      assertDoesNotThrow(() -> classFile.newInstance());
     }
   }
 }
