@@ -27,6 +27,7 @@
 // THE POSSIBILITY OF SUCH DAMAGE.
 package org.objectweb.asm.util;
 
+import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -63,6 +64,22 @@ class CheckFrameAnalyzerTest extends AsmTest {
   // Labels used to generate test cases.
   private final Label label0 = new Label();
 
+  @Test
+  void testAnalyze_validBytecode() {
+    MethodNode methodNode =
+        new MethodNodeBuilder("(Ljava/lang/Object;)V", 1, 2)
+            .aload(0)
+            .astore(1)
+            .iconst_0()
+            .istore(0)
+            .vreturn()
+            .build();
+
+    Executable analyze = () -> newAnalyzer().analyze(CLASS_NAME, methodNode);
+
+    assertDoesNotThrow(analyze);
+  }
+
   @Test
   void testAnalyze_invalidJsr() {
     MethodNode methodNode = new MethodNodeBuilder().jsr(label0).label(label0).vreturn().build();
