@@ -33,6 +33,7 @@ import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.HashMap;
+import java.util.Map;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.function.Executable;
 import org.objectweb.asm.ClassWriter;
@@ -122,7 +123,7 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
   @Test
   void testVisitCode_abstractMethod() {
     CheckMethodAdapter checkAbstractMethodAdapter =
-        new CheckMethodAdapter(Opcodes.ACC_ABSTRACT, "m", "()V", null, new HashMap<>());
+        new CheckMethodAdapter(Opcodes.ACC_ABSTRACT, "m", "()V", null, Map.of());
 
     Executable visitCode = () -> checkAbstractMethodAdapter.visitCode();
 
@@ -434,7 +435,8 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
     Executable visitMethodInsn = () -> checkMethodAdapter.visitMethodInsn(42, "o", "m", "()V");
 
     Exception exception = assertThrows(IllegalArgumentException.class, visitMethodInsn);
-    assertEquals("Invalid opcode: 42", exception.getMessage());
+    assertEquals(
+        "Invalid combination of opcode and method: 42, VISIT_METHOD_INSN", exception.getMessage());
   }
 
   @Test
@@ -445,7 +447,8 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
         () -> checkMethodAdapter.visitMethodInsn(42, "o", "m", "()V", false);
 
     Exception exception = assertThrows(IllegalArgumentException.class, visitMethodInsn);
-    assertEquals("Invalid opcode: 42", exception.getMessage());
+    assertEquals(
+        "Invalid combination of opcode and method: 42, VISIT_METHOD_INSN", exception.getMessage());
   }
 
   @Test
@@ -1084,7 +1087,7 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
   @Test
   void testVisitEnd_invalidDataFlow() {
     MethodVisitor dataFlowCheckMethodAdapter =
-        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)I", null, new HashMap<>());
+        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)I", null, Map.of());
     dataFlowCheckMethodAdapter.visitCode();
     dataFlowCheckMethodAdapter.visitVarInsn(ILOAD, 1);
     dataFlowCheckMethodAdapter.visitVarInsn(ASTORE, 0);
@@ -1108,11 +1111,11 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
     MethodVisitor methodVisitor =
         new CheckMethodAdapter.MethodWriterWrapper(
             /* latest api = */ Opcodes.ASM9,
-            /* version = */ Opcodes.V1_5,
+            /* version= */ Opcodes.V1_5,
             classWriter,
             new MethodVisitor(/* latest api = */ Opcodes.ASM9) {});
     MethodVisitor dataFlowCheckMethodAdapter =
-        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)I", methodVisitor, new HashMap<>());
+        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)I", methodVisitor, Map.of());
     dataFlowCheckMethodAdapter.visitCode();
     dataFlowCheckMethodAdapter.visitVarInsn(ILOAD, 1);
     dataFlowCheckMethodAdapter.visitInsn(IRETURN);
@@ -1129,11 +1132,11 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
     MethodVisitor methodVisitor =
         new CheckMethodAdapter.MethodWriterWrapper(
             /* latest api = */ Opcodes.ASM9,
-            /* version = */ Opcodes.V1_5,
+            /* version= */ Opcodes.V1_5,
             classWriter,
             new MethodVisitor(/* latest api = */ Opcodes.ASM9) {});
     MethodVisitor dataFlowCheckMethodAdapter =
-        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)I", methodVisitor, new HashMap<>());
+        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)I", methodVisitor, Map.of());
     dataFlowCheckMethodAdapter.visitCode();
     dataFlowCheckMethodAdapter.visitVarInsn(ILOAD, 1);
     dataFlowCheckMethodAdapter.visitInsn(IRETURN);
@@ -1150,11 +1153,11 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
     MethodVisitor methodVisitor =
         new CheckMethodAdapter.MethodWriterWrapper(
             /* latest api = */ Opcodes.ASM9,
-            /* version = */ Opcodes.V1_5,
+            /* version= */ Opcodes.V1_5,
             classWriter,
             new MethodVisitor(/* latest api = */ Opcodes.ASM9) {});
     MethodVisitor dataFlowCheckMethodAdapter =
-        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)I", methodVisitor, new HashMap<>());
+        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)I", methodVisitor, Map.of());
     dataFlowCheckMethodAdapter.visitCode();
     dataFlowCheckMethodAdapter.visitVarInsn(ILOAD, 1);
     dataFlowCheckMethodAdapter.visitInsn(IRETURN);
@@ -1175,7 +1178,7 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
     MethodVisitor methodVisitor =
         new CheckMethodAdapter.MethodWriterWrapper(
             /* latest api = */ Opcodes.ASM9,
-            /* version = */ Opcodes.V1_7,
+            /* version= */ Opcodes.V1_7,
             classWriter,
             new MethodVisitor(/* latest api = */ Opcodes.ASM9) {});
     MethodVisitor dataFlowCheckMethodAdapter =
@@ -1200,7 +1203,7 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
     MethodVisitor methodVisitor =
         new CheckMethodAdapter.MethodWriterWrapper(
             /* latest api = */ Opcodes.ASM9,
-            /* version = */ Opcodes.V1_7,
+            /* version= */ Opcodes.V1_7,
             classWriter,
             new MethodVisitor(/* latest api = */ Opcodes.ASM9) {});
     MethodVisitor dataFlowCheckMethodAdapter =
@@ -1226,7 +1229,7 @@ class CheckMethodAdapterTest extends AsmTest implements Opcodes {
   @Test
   void testVisitEnd_invalidReturnType() {
     MethodVisitor dataFlowCheckMethodAdapter =
-        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)V", null, new HashMap<>());
+        new CheckMethodAdapter(ACC_PUBLIC, "m", "(I)V", null, Map.of());
     dataFlowCheckMethodAdapter.visitCode();
     dataFlowCheckMethodAdapter.visitVarInsn(ILOAD, 1);
     dataFlowCheckMethodAdapter.visitInsn(IRETURN);
