@@ -253,6 +253,10 @@ class ConstantsTest {
       case "V18":
       case "V19":
       case "V20":
+      case "V21":
+      case "V22":
+      case "V23":
+      case "V24":
         return ConstantType.CLASS_VERSION;
       case "ACC_PUBLIC":
       case "ACC_PRIVATE":
@@ -561,7 +565,7 @@ class ConstantsTest {
 
   private static int getIntegerValue(final Field field) {
     try {
-      return ((Integer) field.get(null)).intValue();
+      return (int) field.get(null);
     } catch (IllegalAccessException e) {
       throw new IllegalArgumentException(e);
     }
